..
    This file is automatically generated. Do not make
    changes as these will be overwritten. Rather edit
    the docstrings in the source code.

``yaff.analysis`` -- Trajectory analysis
########################################




``yaff.analysis.basic`` -- Basic trajectory analysis routines
=============================================================

.. automodule:: yaff.analysis.basic
    :members:


``yaff.analysis.blav`` -- The block-average method
==================================================

.. automodule:: yaff.analysis.blav
    :members:


``yaff.analysis.diffusion`` -- Diffusion constants
==================================================

.. automodule:: yaff.analysis.diffusion
    :members:


``yaff.analysis.hook`` -- Abstract hook implementation for trajectory analysis
==============================================================================

.. automodule:: yaff.analysis.hook
    :members:


``yaff.analysis.pca`` -- Toolkit for Principal Component Analysis (PCA)
=======================================================================

.. automodule:: yaff.analysis.pca
    :members:


``yaff.analysis.rdf`` -- Radial distribution functions
======================================================

.. automodule:: yaff.analysis.rdf
    :members:


``yaff.analysis.spectrum`` -- Spectral analysis and autocorrelation functions
=============================================================================

.. automodule:: yaff.analysis.spectrum
    :members:


``yaff.analysis.utils`` -- Auxiliary analysis routines
======================================================

.. automodule:: yaff.analysis.utils
    :members:
